@@ -45,7 +45,7 @@ class Subscriber(object):
 
             logger.debug('Subscription callback "%s" succesfully completed.' % method.routing_key)
         except Exception:
-            logger.exception('Subscription callback for method "" error.' % method.routing_key)
+            logger.exception('Subscription callback for method "%s" error.' % method.routing_key)
 
 
 class Method(Subscriber):
